@@ -33,35 +33,37 @@ def extract_features(item: dict, layers_to_use: List[str], extractors_to_use: Li
             raise exceptions.InvalidInputError(f"Layer {layer} not present in document!")
         value = item[layer].lower()
         features.append(f"{word_index}:{layer}={value}")
+
         # add some suffixes from token
         if layer == FEATURE_LAYER_WORD:
             for i in range(suffix_len[0], suffix_len[1]+1):
-                features.append(f"{word_index}:{layer}={value[-i:]}")
-    # extract more features from token
-    token = item[FEATURE_LAYER_WORD]
-    for extractor in extractors_to_use:
-        if extractor == EXTRACTOR_ISUPPER:
-            feature_value = token.isupper()
-            features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
-        elif extractor == EXTRACTOR_ISTITLE:
-            feature_value = token.istitle()
-            features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
-        elif extractor == EXTRACTOR_HASDIGIT:
-            feature_value = has_digit(token)
-            features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
-        # add more token-based extractors here!
+                features.append(f"{word_index}:{layer}.suffix={value[-i:]}")
+
+    if FEATURE_LAYER_WORD in item:
+        # extract more features from token
+        token = item[FEATURE_LAYER_WORD]
+        for extractor in extractors_to_use:
+            if extractor == EXTRACTOR_ISUPPER:
+                feature_value = token.isupper()
+                features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
+            elif extractor == EXTRACTOR_ISTITLE:
+                feature_value = token.istitle()
+                features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
+            elif extractor == EXTRACTOR_HASDIGIT:
+                feature_value = has_digit(token)
+                features.append(f"{word_index}:{FEATURE_LAYER_WORD}.{extractor}={feature_value}")
+            # add more token-based extractors here!
+
     # get similar lemmas from embedding
     if embedding and FEATURE_LAYER_LEMMA in item:
         most_similar_lemmas = embedding.get_similar([item[FEATURE_LAYER_LEMMA]], n=1)
         if len(most_similar_lemmas):
             most_similar_lemma = most_similar_lemmas[0]["phrase"]
-            features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.closest={most_similar_lemma}")
+            features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.embedding={most_similar_lemma}")
         else:
-            features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.closest=NA")
-    
+            features.append(f"{word_index}:{FEATURE_LAYER_LEMMA}.embedding=NA")
     # replace newlines as it breaks taggerinfo()
     features = [f.replace("\n", "") for f in features]
-
     return features
 
 
