@@ -8,23 +8,14 @@ class TaggingReport:
         self.classes = classes
 
         # flatten y
-        y_pred_flat = [j for sub in y_pred for j in sub]
-        y_test_flat = [j for sub in y_test for j in sub]
-
-        # remove "0" class from reporting
-        y_pred = []
-        y_test = []
-        for i, a in enumerate(y_test_flat):
-            if a != "0":
-                y_pred.append(y_pred_flat[i])
-                y_test.append(a)
+        y_pred = [j for sub in y_pred for j in sub]
+        y_test = [j for sub in y_test for j in sub]
 
         self.precision = precision_score(y_test, y_pred, average=self.average)
         self.f1_score = f1_score(y_test, y_pred, average=self.average)
         self.confusion = confusion_matrix(y_test, y_pred)
         self.recall = recall_score(y_test, y_pred, average=self.average)
 
-
     def to_dict(self):
         return {
             "f1_score": round(self.f1_score, 5),
